PointForce2D

Struct PointForce2D 

pub struct PointForce2D {
    pub position_x: f64,
    pub position_y: f64,
    pub force_x: f64,
    pub force_y: f64,
}
A planar force applied at a position relative to a chosen moment point.

Fields

position_x: f64

Horizontal position from the chosen origin.

position_y: f64

Vertical position from the chosen origin.

force_x: f64

Horizontal force component.

force_y: f64

Vertical force component.

Implementations

Source

impl PointForce2D

pub fn new( position_x: f64, position_y: f64, force_x: f64, force_y: f64, ) -> Option<Self>

Creates a new point force when all values are finite.

pub fn moment_about_origin(&self) -> Option<f64>

Returns the moment of this force about the origin.